Public Class Form1
    ' Define possible contact methods.
    Private Enum ContactMethod
        None = 0
        Email
        Phone
        SnailMail
    End Enum

    ' Define a structure to hold addresses.
    Private Structure Address
        Public Id As String
        Public Name As String
        Public Street As String
        Public City As String
        Public State As String
        Public Zip As String
        Public Email As String
        Public Phone As String
        Public PreferredMethod As ContactMethod
    End Structure

    ' Make a Dictionary to hold addresses.
    Private AddressesByName As Dictionary(Of String, Address) =
        New Dictionary(Of String, Address)()
    Private AddressesById As Dictionary(Of String, Address) =
        New Dictionary(Of String, Address)()

    ' Make sure the ComboBox starts with an item selected.
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        cboMethod.SelectedIndex = 0
    End Sub

    ' Add a new address.
    Private Sub btnAdd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAdd.Click
        Dim newAddress As Address
        newAddress.Id = txtId.Text
        newAddress.Name = txtName.Text
        newAddress.Street = txtStreet.Text
        newAddress.City = txtCity.Text
        newAddress.State = txtState.Text
        newAddress.Zip = txtZip.Text
        newAddress.Email = txtEmail.Text
        newAddress.Phone = txtPhone.Text
        newAddress.PreferredMethod =
            CType(cboMethod.SelectedIndex, ContactMethod)

        ' Add the name and address to the dictionary.
        AddressesByName.Add(txtName.Text, newAddress)
        AddressesById.Add(txtId.Text, newAddress)

        ' Get ready for the next one.
        txtId.Clear()
        txtName.Clear()
        txtStreet.Clear()
        txtCity.Clear()
        txtState.Clear()
        txtZip.Clear()
        txtEmail.Clear()
        txtPhone.Clear()
        cboMethod.SelectedIndex = 0

        txtId.Focus()
    End Sub

    ' Look up an address by name.
    Private Sub btnFindName_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnFindName.Click
        ' Get the Address.
        Dim selectedAddress As Address = AddressesByName(txtName.Text)

        ' Display the Address's values.
        txtId.Text = selectedAddress.Id
        txtName.Text = selectedAddress.Name
        txtStreet.Text = selectedAddress.Street
        txtCity.Text = selectedAddress.City
        txtState.Text = selectedAddress.State
        txtZip.Text = selectedAddress.Zip
        txtEmail.Text = selectedAddress.Email
        txtPhone.Text = selectedAddress.Phone
        cboMethod.SelectedIndex =
            CInt(selectedAddress.PreferredMethod)
    End Sub

    ' Remove this entry by name.
    Private Sub btnRemoveName_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRemoveName.Click
        ' Find the entry by name to get the ID.
        Dim selectedAddress As Address = AddressesByName(txtName.Text)

        ' Remove from the dictionaries.
        AddressesByName.Remove(selectedAddress.Name)
        AddressesById.Remove(selectedAddress.Id)

        ' Get ready for the next one.
        txtId.Clear()
        txtName.Clear()
        txtStreet.Clear()
        txtCity.Clear()
        txtState.Clear()
        txtZip.Clear()
        txtEmail.Clear()
        txtPhone.Clear()
        cboMethod.SelectedIndex = 0

        txtId.Focus()
    End Sub

    ' Look up an address by ID.
    Private Sub btnFindId_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnFindId.Click
        ' Get the Address.
        Dim selectedAddress As Address = AddressesById(txtId.Text)

        ' Display the Address's values.
        txtId.Text = selectedAddress.Id
        txtName.Text = selectedAddress.Name
        txtStreet.Text = selectedAddress.Street
        txtCity.Text = selectedAddress.City
        txtState.Text = selectedAddress.State
        txtZip.Text = selectedAddress.Zip
        txtEmail.Text = selectedAddress.Email
        txtPhone.Text = selectedAddress.Phone
        cboMethod.SelectedIndex =
            CInt(selectedAddress.PreferredMethod)
    End Sub

    ' Remove this entry by ID.
    Private Sub btnRemoveId_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRemoveId.Click
        ' Find the entry by ID to get the name.
        Dim selectedAddress As Address = AddressesById(txtId.Text)

        ' Remove from the dictionaries.
        AddressesByName.Remove(selectedAddress.Name)
        AddressesById.Remove(selectedAddress.Id)

        ' Get ready for the next one.
        txtId.Clear()
        txtName.Clear()
        txtStreet.Clear()
        txtCity.Clear()
        txtState.Clear()
        txtZip.Clear()
        txtEmail.Clear()
        txtPhone.Clear()
        cboMethod.SelectedIndex = 0

        txtId.Focus()
    End Sub
End Class
