﻿Public Class PriorityQueue(Of T)
    ' A structure to hold items.
    Private Structure ItemData
        Public Property ItemPriority As Integer
        Public Property Data As T
    End Structure

    ' The list of items.
    Private Items As List(Of ItemData) = New List(Of ItemData)()

    ' Return the number of items in the list.
    Public ReadOnly Property Count As Integer
        Get
            Return Items.Count
        End Get
    End Property

    ' Add an item to the queue.
    Public Sub Add(ByVal newItem As T, ByVal newPriority As Integer)
        ' Make a new ItemData to hold the item.
        Dim newItemData As ItemData = New ItemData() With
            {.Data = newItem, .ItemPriority = newPriority}

        ' Add the item to the queue.
        Items.Add(newItemData)
    End Sub

    ' Get the item with the lowest priority number.
    ' Return the item's priority.
    Public Sub GetItem(ByRef item As T, ByRef priority As Integer)
        ' Make sure we have something in the queue.
        If (Items.Count < 1) Then
            Throw New InvalidOperationException("PriorityQueue is empty")
        End If

        ' Find the best item.
        Dim bestI As Integer = 0
        Dim bestPriority As Integer = Items(bestI).ItemPriority
        For i As Integer = 1 To Items.Count - 1
            If Items(i).ItemPriority < bestPriority Then
                bestI = i
                bestPriority = Items(i).ItemPriority
            End If
        Next i

        ' Save the best item and priority.
        item = Items(bestI).Data
        priority = Items(bestI).ItemPriority

        ' Remove the best item from the queue.
        Items.RemoveAt(bestI)
    End Sub
End Class
