﻿Public Class NewItemForm
    ' Public fields. (They should really be properties.)
    Public ItemName As String
    Public PriceEach, Quantity, TotalPrice As Decimal

    ' Parse the user-entered values and calculate the total price.
    Private Sub btnCalculate_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCalculate.Click
        ' If values are okay, enable the OK button.
        btnOk.Enabled = ValuesAreOk()
    End Sub

    ' Make sure the fields are up to date.
    ' (Note that this repeats code in the other event handler.)
    Private Sub btnOk_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnOk.Click
        ' See if the values are okay.
        If (ValuesAreOk()) Then
            ' The values are okay. Close the dialog.
            Me.DialogResult = DialogResult.OK
        Else
            ' The values are not okay. Disable the OK button.
            btnOk.Enabled = False
        End If
    End Sub

    ' Validate the values. Return true if they are okay.
    ' Display error messages if values are not okay.
    Private Function ValuesAreOk() As Boolean
        ' Validate the item name.
        ItemName = txtItem.Text
        If (ItemName.Length < 1) Then
            MessageBox.Show("Item Name must not be blank.")
            txtItem.Focus()
            Return False
        End If

        ' Validate price each.
        Try
            PriceEach = Decimal.Parse(
                txtPriceEach.Text,
                System.Globalization.NumberStyles.Any)

            If (PriceEach <= 0) Then
                MessageBox.Show("Price Each must be greater than 0.")
                txtPriceEach.Focus()
                Return False
            End If
        Catch ex As Exception
            MessageBox.Show("Price Each must be a dollar amount." & vbCrLf & vbCrLf & ex.Message)
            txtPriceEach.Focus()
            Return False
        End Try

        ' Validate quantity.
        Try
            Quantity = Decimal.Parse(
                txtQuantity.Text,
                System.Globalization.NumberStyles.Any)

            If (Quantity <= 0) Then
                MessageBox.Show("Quantity must be greater than 0.")
                txtQuantity.Focus()
                Return False
            End If
        Catch ex As Exception
            MessageBox.Show("Quantity must be a numeric value." & vbCrLf & vbCrLf & ex.Message)
            txtQuantity.Focus()
            Return False
        End Try

        ' Calculate the total.
        Try
            TotalPrice = PriceEach * Quantity
            txtTotalPrice.Text = TotalPrice.ToString("C")
        Catch ex As Exception
            MessageBox.Show("Error calculating total." & vbCrLf & vbCrLf & ex.Message)
            Return False
        End Try

        ' If we get here, then everything's okay.
        Return True
    End Function
End Class