-- Select the master database.
USE [master];

-- Delete the OrdersDatabase.
-- IF EXISTS (SELECT * FROM sys.databases WHERE name = 'OrdersDatabase')
-- 	DROP DATABASE OrdersDatabase;

-- Create and use the OrdersDatabase.
CREATE DATABASE OrdersDatabase;
GO
USE OrdersDatabase;

-- Create the Customer table.
CREATE TABLE Customer
(
	CustomerId	int				PRIMARY KEY,
	FirstName	nvarchar(50)	NOT NULL,
	LastName	nvarchar(50)	NOT NULL,
)

-- Create the PurchaseOrder table.
CREATE TABLE PurchaseOrder
(
    OrderId		int				PRIMARY KEY,
    OrderDate	datetime		NOT NULL,
    CustomerId	int				NOT NULL
		FOREIGN KEY REFERENCES Customer (CustomerId),
)

-- Create the OrderItem table.
CREATE TABLE OrderItem
(
    OrderId				int				NOT NULL
		FOREIGN KEY REFERENCES PurchaseOrder (OrderId),
    ItemNumber			int				NOT NULL,
	ItemDescription		nvarchar(50)	NOT NULL,
	Quantity			int				NOT NULL,
	CONSTRAINT PK_OrderItem PRIMARY KEY (OrderId, ItemNumber)
)

-- Insert data into the Customer table.
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (1, 'Ann', 'Ashler')
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (2, 'Bob', 'Boggart')
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (3, 'Cindy', 'Carruthers')
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (4, 'Dan', 'Dent')
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (5, 'Edwina', 'Everly')
INSERT INTO Customer (CustomerId, FirstName, LastName) VALUES (6, 'Frank', 'Finicky')

-- Insert data into the PurchaseOrder table.
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1001, '2011-04-01 12:35:10', 1)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1002, '2011-04-14 13:15:20', 2)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1003, '2011-05-08 10:27:30', 3)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1004, '2011-05-19 09:09:40', 1)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1005, '2011-06-22 14:47:50', 2)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1006, '2011-07-03 11:25:00', 3)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1007, '2011-08-20 11:40:05', 2)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1008, '2011-08-21 12:10:15', 4)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1009, '2011-09-06 13:16:25', 3)
INSERT INTO PurchaseOrder (OrderId, OrderDate, CustomerId) VALUES (1010, '2011-04-21 10:27:00', 5)

-- Insert data into the OrderItem table.
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1001, 1, 'Pencil, dozen', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1001, 2, 'Paper, ream', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1002, 1, 'Cookies, dozen', 3);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1002, 2, 'Notepad', 5);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1002, 3, 'Rubber Stamp', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1003, 1, 'Pencil, dozen', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1004, 1, 'Stapler', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1004, 2, 'Staples, box of 1000', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1004, 3, 'Office Chair', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1005, 1, 'Laptop Computer', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1006, 1, 'Rubber Chicken', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 1, 'Dry Erase Marker, Red', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 2, 'Dry Erase Marker, Green', 3);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 3, 'Dry Erase Marker, Blue', 3);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 4, 'Paper Clips, 100', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 5, 'Desktop Lamp', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1007, 6, 'Caffeinated Toothpicks, 100 ct', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1008, 1, 'Stress Management Ball', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1008, 2, 'USB Foam Missile Launcher', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1009, 1, 'Orange Laser Pointer', 1);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1009, 2, 'Mylar Party Balloons, dozen', 2);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1009, 3, 'Copies', 76);
INSERT INTO OrderItem (OrderId, ItemNumber, ItemDescription, Quantity) VALUES (1009, 4, 'Power Squid', 1);
